@@ -195,6 +195,37 @@ class EscriptoriumConnector:
         document_pk: int,
         part_pk: int,
         transcription_pk: int,
+    ) -> Union[bytes, None]:
+        return self.__download_part_output_transcription(
+            document_pk, part_pk, transcription_pk, "alto"
+        )
+
+    def download_part_pagexml_transcription(
+        self,
+        document_pk: int,
+        part_pk: int,
+        transcription_pk: int,
+    ) -> Union[bytes, None]:
+        return self.__download_part_output_transcription(
+            document_pk, part_pk, transcription_pk, "pagexml"
+        )
+
+    def download_part_text_transcription(
+        self,
+        document_pk: int,
+        part_pk: int,
+        transcription_pk: int,
+    ) -> Union[bytes, None]:
+        return self.__download_part_output_transcription(
+            document_pk, part_pk, transcription_pk, "text"
+        )
+
+    def __download_part_output_transcription(
+        self,
+        document_pk: int,
+        part_pk: int,
+        transcription_pk: int,
+        output_type: str,
     ) -> Union[bytes, None]:
         if self.cookie is None:
             raise Exception("Must use websockets to download ALTO exports")
@@ -211,7 +242,7 @@ class EscriptoriumConnector:
                 "document": document_pk,
                 "parts": part_pk,
                 "transcription": transcription_pk,
-                "file_format": "alto",
+                "file_format": output_type,
             },
         )
 
@@ -237,7 +268,7 @@ class EscriptoriumConnector:
 
         return alto_request.content
 
-    def upload_part_alto_transcription(
+    def upload_part_transcription(
         self,
         document_pk: int,
         part_pk: int,
@@ -245,6 +276,19 @@ class EscriptoriumConnector:
         filename: str,
         file_data: BufferedReader,
     ):
+        """Upload a txt, PageXML, or ALTO file.
+
+        Args:
+            document_pk (int): Document PK
+            part_pk (int): Part PK
+            transcription_name (str): Transcription name
+            filename (str): Filename
+            file_data (BufferedReader): File data as a BufferedReader
+
+        Returns:
+            null: Nothing
+        """
+
         return self.__post_url(
             f"{self.api_url}documents/{document_pk}/imports/",
             {
@@ -300,6 +344,9 @@ class EscriptoriumConnector:
         return r
 
     def create_document_part_region(self, doc_pk: int, part_pk: int, region: object):
+        if not isinstance(region["box"], str):
+            region["box"] = json.dumps(region["box"])
+
         r = self.__post_url(
             f"{self.api_url}documents/{doc_pk}/parts/{part_pk}/blocks/",
             region,
